README
======

Documentation at https://alkali.readthedocs.org

.. image:: https://readthedocs.org/projects/alkali/badge/?version=master
.. image:: https://travis-ci.org/kneufeld/alkali.svg?branch=master
.. image:: https://codecov.io/gh/kneufeld/alkali/branch/master/graph/badge.svg
.. image:: https://coveralls.io/repos/github/kneufeld/alkali/badge.svg?branch=master
